==> atrium-cc-de_CH-robstoll-js-0.9.2.jar: atrium-cc-de_CH-robstoll-js.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'atrium-core-robstoll-js', 'atrium-domain-robstoll-js'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('atrium-core-robstoll-js'), require('atrium-domain-robstoll-js'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'atrium-cc-de_CH-robstoll-js'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'atrium-cc-de_CH-robstoll-js'.");
    }
    if (typeof this['atrium-core-robstoll-js'] === 'undefined') {
      throw new Error("Error loading module 'atrium-cc-de_CH-robstoll-js'. Its dependency 'atrium-core-robstoll-js' was not found. Please, check whether 'atrium-core-robstoll-js' is loaded prior to 'atrium-cc-de_CH-robstoll-js'.");
    }
    if (typeof this['atrium-domain-robstoll-js'] === 'undefined') {
      throw new Error("Error loading module 'atrium-cc-de_CH-robstoll-js'. Its dependency 'atrium-domain-robstoll-js' was not found. Please, check whether 'atrium-domain-robstoll-js' is loaded prior to 'atrium-cc-de_CH-robstoll-js'.");
    }
    root['atrium-cc-de_CH-robstoll-js'] = factory(typeof this['atrium-cc-de_CH-robstoll-js'] === 'undefined' ? {} : this['atrium-cc-de_CH-robstoll-js'], kotlin, this['atrium-core-robstoll-js'], this['atrium-domain-robstoll-js']);
  }
}(this, function (_, Kotlin, $module$atrium_core_robstoll_js, $module$atrium_domain_robstoll_js) {
  'use strict';
  var dependOn_atrium_core_robstoll = $module$atrium_core_robstoll_js.ch.tutteli.atrium.core.robstoll.dependOn_atrium_core_robstoll;
  var dependOn_atrium_domain_robstoll = $module$atrium_domain_robstoll_js.ch.tutteli.atrium.domain.robstoll.dependOn_atrium_domain_robstoll;
  function dependOnAtrium() {
    dependOn_atrium_core_robstoll();
    dependOn_atrium_domain_robstoll();
  }
  var package$ch = _.ch || (_.ch = {});
  var package$tutteli = package$ch.tutteli || (package$ch.tutteli = {});
  var package$atrium = package$tutteli.atrium || (package$tutteli.atrium = {});
  var package$cc = package$atrium.cc || (package$atrium.cc = {});
  var package$de_CH = package$cc.de_CH || (package$cc.de_CH = {});
  var package$robstoll = package$de_CH.robstoll || (package$de_CH.robstoll = {});
  package$robstoll.dependOnAtrium = dependOnAtrium;
  Kotlin.defineModule('atrium-cc-de_CH-robstoll-js', _);
  return _;
}));

//# sourceMappingURL=atrium-cc-de_CH-robstoll-js.js.map

==> atrium-cc-de_CH-robstoll-js-0.13.0.jar: atrium-cc-de_CH-robstoll-js.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'atrium-core-robstoll-js', 'atrium-domain-robstoll-js'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('atrium-core-robstoll-js'), require('atrium-domain-robstoll-js'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'atrium-cc-de_CH-robstoll-js'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'atrium-cc-de_CH-robstoll-js'.");
    }if (typeof this['atrium-core-robstoll-js'] === 'undefined') {
      throw new Error("Error loading module 'atrium-cc-de_CH-robstoll-js'. Its dependency 'atrium-core-robstoll-js' was not found. Please, check whether 'atrium-core-robstoll-js' is loaded prior to 'atrium-cc-de_CH-robstoll-js'.");
    }if (typeof this['atrium-domain-robstoll-js'] === 'undefined') {
      throw new Error("Error loading module 'atrium-cc-de_CH-robstoll-js'. Its dependency 'atrium-domain-robstoll-js' was not found. Please, check whether 'atrium-domain-robstoll-js' is loaded prior to 'atrium-cc-de_CH-robstoll-js'.");
    }root['atrium-cc-de_CH-robstoll-js'] = factory(typeof this['atrium-cc-de_CH-robstoll-js'] === 'undefined' ? {} : this['atrium-cc-de_CH-robstoll-js'], kotlin, this['atrium-core-robstoll-js'], this['atrium-domain-robstoll-js']);
  }
}(this, function (_, Kotlin, $module$atrium_core_robstoll_js, $module$atrium_domain_robstoll_js) {
  'use strict';
  var dependOn_atrium_core_robstoll = $module$atrium_core_robstoll_js.ch.tutteli.atrium.core.robstoll.dependOn_atrium_core_robstoll;
  var dependOn_atrium_domain_robstoll = $module$atrium_domain_robstoll_js.ch.tutteli.atrium.domain.robstoll.dependOn_atrium_domain_robstoll;
  function dependOnAtrium() {
    dependOn_atrium_core_robstoll();
    dependOn_atrium_domain_robstoll();
  }
  var package$ch = _.ch || (_.ch = {});
  var package$tutteli = package$ch.tutteli || (package$ch.tutteli = {});
  var package$atrium = package$tutteli.atrium || (package$tutteli.atrium = {});
  var package$cc = package$atrium.cc || (package$atrium.cc = {});
  var package$de_CH = package$cc.de_CH || (package$cc.de_CH = {});
  var package$robstoll = package$de_CH.robstoll || (package$de_CH.robstoll = {});
  package$robstoll.dependOnAtrium = dependOnAtrium;
  Kotlin.defineModule('atrium-cc-de_CH-robstoll-js', _);
  return _;
}));

//# sourceMappingURL=atrium-cc-de_CH-robstoll-js.js.map
